## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----message = FALSE, warning = FALSE, setup----------------------------------
library(GenomicRanges)
library(InteractionSet)
library(plotgardener)
library(TxDb.Hsapiens.UCSC.hg38.knownGene)
library(DegCre)

## ----demo inputs--------------------------------------------------------------
data(DexNR3C1)
lapply(DexNR3C1,head)

## ----demo DegCre default------------------------------------------------------
myDegCreResList <- runDegCre(DegGR=DexNR3C1$DegGR,
                             DegP=DexNR3C1$DegGR$pVal,
                             DegLfc=DexNR3C1$DegGR$logFC,
                             CreGR=DexNR3C1$CreGR,
                             CreP=DexNR3C1$CreGR$pVal,
                             CreLfc=DexNR3C1$CreGR$logFC,
                             reqEffectDirConcord=TRUE,
                             verbose=FALSE)

## ----demo DegCre result list--------------------------------------------------
names(myDegCreResList)
head(myDegCreResList$degCreHits)

## ----demo subsetting----------------------------------------------------------
passFDR <- which(mcols(myDegCreResList$degCreHits)$assocProbFDR <= 0.05)
passProb <- which(mcols(myDegCreResList$degCreHits)$assocProb >= 0.25)

keepDegCreHits <- myDegCreResList$degCreHits[intersect(passFDR,passProb)]

keepDegCreHits

## ----demo GR subset-----------------------------------------------------------

myDegCreResList$DegGR[queryHits(keepDegCreHits)]

myDegCreResList$CreGR[subjectHits(keepDegCreHits)]

## ----demo Alpha opt-----------------------------------------------------------
alphaOptList <- optimizeAlphaDegCre(DegGR=DexNR3C1$DegGR,
                                    DegP=DexNR3C1$DegGR$pVal,
                                    DegLfc=DexNR3C1$DegGR$logFC,
                                    CreGR=DexNR3C1$CreGR,
                                    CreP=DexNR3C1$CreGR$pVal,
                                    CreLfc=DexNR3C1$CreGR$logFC,
                                    reqEffectDirConcord=TRUE,
                                    verbose=FALSE)

alphaOptList$alphaPRMat

bestAlphaId <- which.max(alphaOptList$alphaPRMat[,4])

bestDegCreResList <- alphaOptList$degCreResListsByAlpha[[bestAlphaId]]

## ----demo assoc dist plot, dpi=200, fig.height=2.5,fig.width=3.5,fig.align='center'----
par(mai=c(0.4,0.55,0.05,0.05))
par(mgp=c(1,0.4,0))
par(bty="l")

binStats <- plotDegCreAssocProbVsDist(degCreResList=bestDegCreResList,
                                      assocProbFDRThresh=0.05)

## ----demo plot bin algorithm, dpi=200, fig.height=2,fig.width=2.3,fig.align='center'----
par(mai=c(0.5,0.5,0.05,0.3))
par(mgp=c(1,0.4,0))
par(bty="l")
par(cex.lab=0.6)
par(cex.axis=0.5)
plotDegCreBinHeuristic(degCreResList=bestDegCreResList)

## ----demo plot PR curve, dpi=200, fig.height=1.75,fig.width=1.75,fig.align='center'----
par(mai=c(0.5,0.5,0.05,0.2))
par(mgp=c(1,0.4,0))
par(cex.lab=0.6)
par(cex.axis=0.5)
par(bty="l")
degCrePRAUC(degCreResList=bestDegCreResList)

## ----demo expect associations-------------------------------------------------
expectAssocPerDegDf <- getExpectAssocPerDEG(degCreResList=bestDegCreResList,
                                            geneNameColName="GeneSymb",
                                            assocAlpha=0.05)

## ----demo expect DataFrame----------------------------------------------------
head(expectAssocPerDegDf)

## ----demo plot expect hist, dpi=200,  fig.height=2,fig.width=2.5,fig.align='center'----
par(mai=c(0.5,0.5,0.15,0.05))
par(mgp=c(1,0.4,0))
par(bty="l")
par(cex.lab=0.6)
par(cex.axis=0.5)
plotExpectedAssocsPerDeg(expectAssocPerDegDf=expectAssocPerDegDf)

## ----browser1, echo=TRUE, dpi=200,fig.height=2, fig.width=3.5, message=FALSE,warning=FALSE,fig.align='center'----
browserOuts <- plotBrowserDegCre(degCreResList=bestDegCreResList,
                                 geneName="ERRFI1",
                                 geneNameColName="GeneSymb",
                                 CreSignalName="NR3C1",
                                 plotWidth=3.5,
                                 plotHeight=2)

## ----demo zoom browser--------------------------------------------------------
zoomGR <- GRanges(seqnames="chr1",
                  ranges=IRanges(start=7900e3,end=8400e3))

## ----demo highlight browser---------------------------------------------------
geneHighDf <- data.frame(gene=bestDegCreResList$DegGR$GeneSymb,
                         col="gray")
geneHighDf[which(geneHighDf$gene=="ERRFI1"),2] <- "black"

## ----demo convert to GInter---------------------------------------------------
degCreGInter <-
    convertdegCreResListToGInteraction(degCreResList=bestDegCreResList,
                                       assocAlpha=0.05)

degCreGInter

## ----demo convert to DataFrame------------------------------------------------
degCreDf <- convertDegCreDataFrame(degCreResList=bestDegCreResList,
                                   assocAlpha=0.05)

head(degCreDf)

## -----------------------------------------------------------------------------
sessionInfo()

